@@ -31,6 +31,7 @@
 
 #include "file-data.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "fr-command.h"
 #include "fr-command-7z.h"
 
@@ -335,6 +336,8 @@ fr_command_7z_class_init (FRCommand7zClass *class)
 static void 
 fr_command_7z_init (FRCommand *comm)
 {
+	comm->file_type = FR_FILE_TYPE_7ZIP;
+
 	comm->propAddCanUpdate             = TRUE; 
 	comm->propAddCanReplace            = TRUE; 
 	comm->propExtractCanAvoidOverwrite = FALSE;
