@@ -31,6 +31,7 @@
 
 #include "file-data.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "fr-command.h"
 #include "fr-command-zip.h"
 
@@ -204,7 +205,7 @@ add_password_arg (FRCommand     *comm,
 
 		fr_process_add_arg (comm->process, "-P");
 
-		e_password = escape_str (password, "\"");
+		e_password = escape_str (password, "\"*?[]'`()$!;");
 		if (e_password != NULL) {
 			arg = g_strconcat ("\"", e_password, "\"", NULL);
 			g_free (e_password);
@@ -248,10 +249,9 @@ process_line__common (char     *line,
 	fr_command_message (comm, line);
 
 	if (comm->n_files != 0) {
-		double fraction = (double) comm->n_file++ / comm->n_files;
+		double fraction = (double) comm->n_file++ / (comm->n_files+1);
 		fr_command_progress (comm, fraction);
 	}
-
 }
 
 
@@ -426,6 +426,8 @@ fr_command_zip_class_init (FRCommandZipClass *class)
 static void 
 fr_command_zip_init (FRCommand *comm)
 {
+	comm->file_type = FR_FILE_TYPE_ZIP;
+
 	comm->propAddCanUpdate             = TRUE; 
 	comm->propAddCanReplace            = TRUE; 
 	comm->propExtractCanAvoidOverwrite = TRUE;
@@ -484,8 +486,8 @@ fr_command_zip_new (FRProcess  *process,
 {
 	FRCommand *comm;
 
-	if ((!is_program_in_path("zip")) ||
-	    (!is_program_in_path("unzip"))) {
+	if (!is_program_in_path ("zip") &&
+	    !is_program_in_path ("unzip")) {
 		return NULL;
 	}
 
