@@ -26,6 +26,7 @@
 #include <glib.h>
 #include "file-data.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "fr-process.h"
 #include "fr-command.h"
 #include "fr-marshal.h"
@@ -233,7 +234,7 @@ fr_command_init (FRCommand *comm)
 
 static void 
 fr_command_start (FRProcess *process,
-		  gpointer data)
+		  gpointer   data)
 {
 	FRCommand *comm = FR_COMMAND (data);
 	g_signal_emit (G_OBJECT (comm), 
@@ -244,26 +245,31 @@ fr_command_start (FRProcess *process,
 
 
 static void 
-fr_command_done (FRProcess *process,
+fr_command_done (FRProcess   *process,
 		 FRProcError *error, 
-		 gpointer data)
+		 gpointer     data)
 {
 	FRCommand *comm = FR_COMMAND (data);
 
 	if (error->type != FR_PROC_ERROR_NONE) 
 		fr_command_handle_error (comm, error);
+	else
+		comm->process->restart = FALSE;
 
-	g_signal_emit (G_OBJECT (comm),
-		       fr_command_signals[DONE], 
-		       0,
-		       comm->action, 
-		       error);
+	if (comm->process->restart)
+		fr_process_start (comm->process);
+	else
+		g_signal_emit (G_OBJECT (comm),
+			       fr_command_signals[DONE], 
+			       0,
+			       comm->action, 
+			       error);
 }
 
 
 void
-fr_command_construct (FRCommand *comm,
-		      FRProcess *process,
+fr_command_construct (FRCommand  *comm,
+		      FRProcess  *process,
 		      const char *fr_command_name)
 {
 	fr_command_set_filename (comm, fr_command_name);
@@ -343,10 +349,8 @@ fr_command_set_filename (FRCommand *comm,
 
 	comm->e_filename = shell_escape (comm->filename);
 
-#ifdef DEBUG
-	g_print ("filename : %s\n", comm->filename);
-	g_print ("e_filename : %s\n", comm->e_filename);
-#endif
+	debug (DEBUG_INFO, "filename : %s\n", comm->filename);
+	debug (DEBUG_INFO, "e_filename : %s\n", comm->e_filename);
 }
 
 
@@ -367,24 +371,7 @@ fr_command_list (FRCommand *comm)
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 	fr_process_set_err_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 
-	if (comm->fake_load) {
-
-#ifdef DEBUG
-		g_print ("FAKE LOAD\n");
-#endif
-
-		g_signal_emit (G_OBJECT (comm), 
-			       fr_command_signals[START], 
-			       0,
-			       comm->action);
-
-		comm->process->error.type = FR_PROC_ERROR_NONE;
-		g_signal_emit (G_OBJECT (comm), 
-			       fr_command_signals[DONE], 
-			       0,
-			       comm->action,
-			       &comm->process->error);
-	} else 
+	if (!comm->fake_load) 
 		FR_COMMAND_GET_CLASS (G_OBJECT (comm))->list (comm);
 }
 
@@ -486,9 +473,12 @@ fr_command_escape (FRCommand     *comm,
 }
 
 
-/* fraction == -1 means : I don't known how much time the current operation will take, 
- *                        the dialog will display this info pulsing the progress bar. 
- * fraction in [0.0, 1.0] means the amount of work, in percentage, accomplished. */
+/* fraction == -1 means : I don't known how much time the current operation 
+ *                        will take, the dialog will display this info pulsing 
+ *                        the progress bar. 
+ * fraction in [0.0, 1.0] means the amount of work, in percentage, 
+ *                        accomplished. 
+ */
 void
 fr_command_progress (FRCommand     *comm,
 		     double         fraction)
