@@ -32,8 +32,9 @@
 #include <glib.h>
 #include "fr-process.h"
 #include "fr-marshal.h"
+#include "glib-utils.h"
 
-#define REFRESH_RATE 10
+#define REFRESH_RATE 20
 
 enum {
 	START,
@@ -456,23 +457,31 @@ process_output (FRProcess *fr_proc)
 	if ((n < 0) && (errno == EINTR))
 		goto again;
 
-	if (n <= 0)
+	if (n < 0)
 		return FALSE;
 
 	fr_proc->o_buffer[fr_proc->o_not_processed + n] = 0;
 
 	line = fr_proc->o_buffer;
-	while ((eol = strchr (line, '\n')) != NULL) {
-		*eol = 0;
+	while (*line != 0) {
+		eol = strchr (line, '\n');
+		
+		if (eol != NULL)
+			*(eol++) = 0;
+		else if (n == 0) /* EOF on file descriptor */
+			eol = line + strlen (line);
+		else 
+			break;
 
 		fr_proc->raw_output = g_list_prepend (fr_proc->raw_output, 
 						      g_strdup (line));
 
-		if ((fr_proc->o_proc_line_func != NULL) && (line != NULL)) {
+		if (fr_proc->o_proc_line_func != NULL) {
+			g_assert (line != NULL);
 			(*fr_proc->o_proc_line_func) (line, fr_proc->o_proc_line_data);
 		}
 
-		line = eol + 1;
+		line = eol;
 	}
 	
 	/* shift unprocessed text to the beginning. */
@@ -481,7 +490,7 @@ process_output (FRProcess *fr_proc)
 	for (i = 0; *line != 0; line++, i++)
 		fr_proc->o_buffer[i] = *line;
 
-	return TRUE;
+	return n > 0;
 }
 
 
@@ -499,23 +508,31 @@ process_error (FRProcess *fr_proc)
 	if ((n < 0) && (errno == EINTR))
 		goto again;
 
-	if (n <= 0)
+	if (n < 0)
 		return FALSE;
 
 	fr_proc->e_buffer[fr_proc->e_not_processed + n] = 0;
 
 	line = fr_proc->e_buffer;
-	while ((eol = strchr (line, '\n')) != NULL) {
-		*eol = 0;
+	while (*line != 0) {
+		eol = strchr (line, '\n');
+		
+		if (eol != NULL)
+			*(eol++) = 0;
+		else if (n == 0) /* EOF on file descriptor */
+			eol = line + strlen (line);
+		else 
+			break;
 
 		fr_proc->raw_error = g_list_prepend (fr_proc->raw_error, 
 						     g_strdup (line));
 
-		if ((fr_proc->e_proc_line_func != NULL) && (line != NULL)) {
+		if (fr_proc->e_proc_line_func != NULL) {
+			g_assert (line != NULL);
 			(*fr_proc->e_proc_line_func) (line, fr_proc->e_proc_line_data);
 		}
 
-		line = eol + 1;
+		line = eol;
 	}
 	
 	/* shift unprocessed text to the beginning. */
@@ -524,7 +541,7 @@ process_error (FRProcess *fr_proc)
 	for (i = 0; *line != 0; line++, i++)
 		fr_proc->e_buffer[i] = *line;
 
-	return TRUE;
+	return n > 0;
 }
 
 
@@ -550,20 +567,15 @@ start_current_command (FRProcess *fr_proc)
 	char          **argv;
 	int             i = 0;
 
-#ifdef DEBUG
-	g_print ("%d/%d) ", fr_proc->current_command, fr_proc->n_comm);
-#endif
+	debug (DEBUG_INFO, "%d/%d) ", fr_proc->current_command, fr_proc->n_comm);
 	
 	c_info = g_ptr_array_index (fr_proc->comm, 
 				    fr_proc->current_command);
 	arg_list = c_info->args;
 	dir = c_info->dir;
 
-	if (dir != NULL) {
-#ifdef DEBUG
-		g_print ("cd %s\n", dir); 
-#endif
-	}
+	if (dir != NULL) 
+		debug (DEBUG_INFO, "cd %s\n", dir); 
 	
 	command = NULL;
 	
@@ -580,12 +592,12 @@ start_current_command (FRProcess *fr_proc)
 	
 	argv[i++] = command->str;
 	argv[i] = NULL;
-	
+
 #ifdef DEBUG
 	{
 		int j;
 		
-		g_print ("/bin/sh "); 
+		g_print ("/bin/sh ");
 		for (j = 0; j < i; j++)
 			g_print ("%s ", argv[j]);
 		g_print ("\n"); 
@@ -695,7 +707,7 @@ check_child (gpointer data)
 
 	if (c_info->ignore_error) {
 		fr_proc->error.type = FR_PROC_ERROR_NONE;
-		g_print ("[ignore error]\n");
+		debug (DEBUG_INFO, "[ignore error]\n");
 	}
 
 	if (fr_proc->error.type != FR_PROC_ERROR_STOPPED) {
@@ -716,10 +728,8 @@ check_child (gpointer data)
 
 	/* Read all pending output. */
 
-	if (fr_proc->error.type == FR_PROC_ERROR_NONE) {
-		while (process_output (fr_proc)) ;
-		while (process_error (fr_proc)) ;
-	}
+	while (process_output (fr_proc)) ;
+	while (process_error (fr_proc)) ;
 
 	close (fr_proc->output_fd);
 	close (fr_proc->error_fd);
